## Version 0.9.3

This release introduces enhancements to the BaseMessage class by adding string addition operations, improving the flexibility and usability of message handling in the llamabot components.

### New Features

- Added the ability to append strings to the beginning and end of BaseMessage content. This update includes the implementation of `__add__` for left addition and `__radd__` for right addition of strings, allowing for more intuitive message construction. (5097fe8) (Eric Ma)

### Bug Fixes

- None in this release.

### Deprecations

- None in this release.
